# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Annotations.AnnotationsEnums

Module implementing some enums for function type annotations.

### Global Attributes

None

### Classes

AnnotationType | Class representing the kind of missing type annotation.
ClassDecoratorType | Class representing the various class method decorators.
FunctionType | Class representing the various function types.

### Functions

None

## AnnotationType

Class representing the kind of missing type annotation.

### Derived from

enum.Enum

### Class Attributes

ARGS
KWARG
KWONLYARGS
POSONLYARGS
RETURN
VARARG

### Class Methods

None

### Methods

None

### Static Methods

None

Up

## ClassDecoratorType

Class representing the various class method decorators.

### Derived from

enum.Enum

### Class Attributes

CLASSMETHOD
STATICMETHOD

### Class Methods

None

### Methods

None

### Static Methods

None

Up

## FunctionType

Class representing the various function types.

### Derived from

enum.Enum

### Class Attributes

PRIVATE
PROTECTED
PUBLIC
SPECIAL

### Class Methods

None

### Methods

None

### Static Methods

None

Up